import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import dayjs from 'dayjs';

import { type FormSchemaGetter } from '#/adapter/form';
import { REPAIR_REQ_TYPE } from '#/constants/dict';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

const curDateTime = dayjs().format('YYYY-MM-DD HH:mm:ss');

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'resCode',
    label: '维修单号'
  },
  {
    component: 'Input',
    fieldName: 'reqCode',
    label: '报修单号'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.REPAIR_RES_STATUS)
    },
    fieldName: 'status',
    label: '状态'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'resDept',
    label: '维修部门'
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'resUser',
    label: '维修人'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '维修单号',
    field: 'resCode',
    minWidth: 160,
    fixed: 'left'
  },
  {
    title: '维修状态',
    field: 'status',
    minWidth: 100,
    fixed: 'left',
    slots: {
      default: ({ row }) => {
        if (row.status === null || row.status === '') {
          return '';
        }
        return renderDict(row.status, DictEnum.REPAIR_RES_STATUS);
      }
    }
  },
  {
    title: '报修单号',
    field: 'reqCode',
    minWidth: 160,
  },
  {
    title: '维修部门',
    field: 'resDeptName',
    minWidth: 100
  },
  {
    title: '维修人',
    field: 'resUserName',
    minWidth: 100
  },
  {
    title: '报修类型',
    field: 'reqType',
    sortable: true,
    minWidth: 100,
    slots: {
      default: ({ row }) => {
        if (row.reqType === null || row.reqType === '') {
          return '';
        }
        return renderDict(row.reqType, DictEnum.REPAIR_REQ_TYPE);
      }
    }
  },
  {
    title: '报修时间',
    field: 'reqTime',
    sortable: true,
    minWidth: 200
  },
  {
    title: '设备(工具)名称',
    sortable: true,
    minWidth: 150,
    slots: {
      default: ({ row }) => {
        if (!row.reqType) {
          return '';
        }

        // 根据不同的请求类型返回相应的名称
        switch (row.reqType) {
          case REPAIR_REQ_TYPE.EQU: {
            return row.equName;
          }
          case REPAIR_REQ_TYPE.FIXTURE: {
            return row.fixtureName;
          }
          default: {
            // 如果请求类型既不是 EQU 也不是 FIXTURE，则返回空字符串
            return '';
          }
        }
      }
    }
  },
  {
    title: '故障类别',
    field: 'faultType',
    minWidth: 100,
    slots: {
      default: ({ row }) => {
        if (row.faultType === null || row.faultType === '') {
          return '';
        }
        return renderDict(row.faultType, DictEnum.REPAIR_FAULT_TYPE);
      }
    }
  },
  {
    title: '报修部门',
    field: 'reqDeptName',
    minWidth: 100
  },
  {
    title: '报修人',
    field: 'reqUserName',
    minWidth: 100
  },
  {
    title: '故障描述',
    field: 'reqDesc',
    minWidth: 120
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 130
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    fieldName: 'reqId',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    label: '报修id'
  },
  {
    component: 'Input',
    fieldName: 'reqUser',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    label: '报修人'
  },
  {
    component: 'Input',
    fieldName: 'reqDept',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    label: '报修部门'
  },
  {
    component: 'Input',
    fieldName: 'reqCode',
    label: '报修单号'
  },
  {
    component: 'Input',
    fieldName: 'resCode',
    label: '维修单号'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'resReason',
    label: '原因分析'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'resHandle',
    label: '处理措施'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'resPrevent',
    label: '预防措施'
  },
  {
    component: 'Input',
    fieldName: 'fixtureName',
    label: '工具名称',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'fixtureId',
    label: '工具id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.REPAIR_RES_STATUS)
    },
    fieldName: 'status',
    defaultValue: '0',
    label: '维修状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    defaultValue: curDateTime,
    fieldName: 'startTime',
    label: '开始时间'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'endTime',
    label: '结束时间'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'resDept',
    label: '维修部门',
    help: `报修人员所属部门`
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'resUser',
    label: '维修人'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'remark',
    label: '备注'
  },
];


